Join Failed TestCase

Join failed
setSpeed | 400 |
open | / |
clickAndWait | //button[@id='join_chat'] |
verifyElementPresent | //ul[@class='errorlist'] |
verifyText | //ul[@class='errorlist']/li | This field is required.
type | //input[@id='id_chat_token'] | 5561b50bb82b9c15ab222b08
clickAndWait | //button[@id='join_chat'] |
verifyElementPresent | //ul[@class='errorlist'] |
verifyText | //ul[@class='errorlist']/li | Invalid code.